@@ -1,6 +1,6 @@
 import requests
-from ..config import base_url, api_token
-
+#from ..config import base_url, api_token
+base_url = "https://dev-aicloud-gateway.logicplum.com/api/v2"
 def read_file(file_path):
     with open(file_path, "rb") as file:
         uploaded_filename = file_path.split('\\')[-1]
@@ -85,10 +85,57 @@ def get_jobdetails(app_id,client_token):
     headers = {"Authorization":client_token}
     response = requests.get(url,headers=headers)
     return response.json()
+ 
+def json_check(response):
+    if response.status_code == 200:
+        return response.json()
+    else:
+        return f"Request failed with status code: {response.status_code}"
 
+def get_blueprint(deployment_id,client_token):
+    url = f"{base_url}/training/blueprint"
+    headers = {"Authorization":client_token}
+    data = {
+        "deployment_id" : deployment_id
+    }
+    response = requests.post(url,data=data,headers=headers)
+    return json_check(response)
 
-def get_deploymentdetails(project_id,client_token):
-    url = f"{base_url}/training/deployment-details/{project_id}"
+def get_deploymentdetails(deployment_id,client_token):
+    url = f"{base_url}/training/deployment/{deployment_id}"
     headers = {"Authorization":client_token}
     response = requests.get(url,headers=headers)
-    return response.json()
\ No newline at end of file
+    return json_check(response)
+    
+def get_project_details(project,client_token):
+    url = f"{base_url}/training/project/{project}"
+    headers = {"Authorization":client_token}
+    response = requests.get(url,headers=headers)
+    return json_check(response)
+
+def delete_deployment(deployment_id,client_token):
+    url = f"{base_url}/training/deployment/{deployment_id}"
+    headers = {"Authorization":client_token}
+    response = requests.delete(url,headers=headers)
+    return json_check(response)
+
+def delete_multiple_deployment(project_id,client_token):
+    url = f"{base_url}/training/deployment-details/{project_id}"
+    headers = {"Authorization":client_token}
+    response = requests.delete(url,headers=headers)
+    return json_check(response)
+
+def delete_project(project,client_token):
+    url = f"{base_url}/training/project/{project}"
+    headers = {"Authorization":client_token}
+    response = requests.delete(url,headers=headers)
+    return json_check(response)
+
+def update_deployment(deployment_id,model_id,client_token):
+    url = f"{base_url}/training/deployment/{deployment_id}"
+    headers = {"Authorization":client_token}
+    data = {
+        "model_id":model_id
+    }
+    response = requests.put(url,data=data,headers=headers)
+    return json_check(response)
