@@ -1,9 +1,33 @@
 import requests
 import base64
+import json
+from PIL import Image as PilImage
+import io
 # from ..config import base_url, api_token
 
 base_url = "https://dev-aicloud-gateway.logicplum.com/api/v2"
 api_token = "i6DmueJGRHw1UYVcyKXmjSprOEWDRtCC7oqxJKuKzz7wXcAHHO9UPUQLlWt23AHx"
+
+def display_response(res_type, response):
+    if res_type == 'base64':
+        return response
+    else:
+        # Check if the response is bytes (for 'image' type)
+        if isinstance(response, bytes) and (response.startswith(b'\x89PNG') or response.startswith(b'\xff\xd8\xff\xe0')):
+            # Open the image
+            image = PilImage.open(io.BytesIO(response))
+            
+            # Convert image to RGB mode if it has an alpha channel
+            if image.mode == 'RGBA':
+                image = image.convert('RGB')
+
+            # Display the image
+            return image
+        else:
+            # Handle the case when response is not bytes as expected for 'image' type
+            response_dict = json.loads(response.decode('utf-8'))
+            return response_dict
+
 def roc_plot(deployment_id,res_type,client_token):
     data = {
     "deployment_id": deployment_id,
@@ -12,7 +36,6 @@ def roc_plot(deployment_id,res_type,client_token):
     url = f"{base_url}/plot/roc"
     headers = {"Authorization":client_token}
     response = requests.post(url, data=data,headers=headers)
-    print(response.text)
     if data.get('res_type') == 'image':
         return response.content
     return response.json()
@@ -123,4 +146,17 @@ def get_allColumns(deployment_id,client_token):
     url = f"{base_url}/plot/dataset-columns//{deployment_id}"
     headers = {"Authorization":client_token}
     response = requests.get(url,headers=headers)
+    return response.json()
+
+def prediction_distribution(deployment_id,res_type,client_token):
+    data = {
+    "deployment_id": deployment_id,
+    "res_type" : res_type 
+    }
+    url = f"{base_url}/plot/prediction-distribution"
+    headers = {"Authorization":client_token}
+    # Send the POST request
+    response = requests.post(url, data=data,headers=headers)
+    if data.get('res_type') == 'image':
+        return response.content
     return response.json()
\ No newline at end of file
